@@ -86,6 +86,9 @@ utils::globalVariables(c(".", "label", "prz", "frq", "ypos", "wb", "ia", "mw", "
 #'          should be printed or not.
 #' @param show.prc logical, if \code{TRUE} (default), percentage values are plotted to each bar
 #'          If \code{FALSE}, percentage values are removed.
+#' @param show.ci Logical, if \code{TRUE)}, adds notches to the box plot, which are
+#'          used to compare groups; if the notches of two boxes do not overlap,
+#'          medians are considered to be significantly different.
 #' @param emph.dots logical, if \code{TRUE}, the groups of dots in a dot-plot are highlighted
 #'          with a shaded rectangle.
 #' @param show.summary logical, if \code{TRUE} (default), a summary with chi-squared
@@ -188,6 +191,7 @@ sjp.grpfrq <- function(var.cnt,
                        show.n = TRUE,
                        show.prc = TRUE,
                        show.axis.values = TRUE,
+                       show.ci = FALSE,
                        show.grpcnt = FALSE,
                        show.legend = TRUE,
                        show.na = FALSE,
@@ -313,7 +317,8 @@ sjp.grpfrq <- function(var.cnt,
         sjmisc::to_value(var.cnt, keep.labels = F),
         size = "auto",
         as.num = TRUE,
-        n = agcnt
+        n = agcnt,
+        append = FALSE
       )
 
     # set value labels
@@ -633,7 +638,7 @@ sjp.grpfrq <- function(var.cnt,
     else
       geob <- geom_line(size = geom.size)
   } else if (type == "boxplot") {
-    geob <- geom_boxplot(width = geom.size)
+      geob <- geom_boxplot(width = geom.size, notch = show.ci)
   } else if (type == "violin") {
     geob <- geom_violin(trim = trimViolin, width = geom.size)
   } else {
@@ -763,8 +768,13 @@ sjp.grpfrq <- function(var.cnt,
     # if we have a violin plot, add an additional boxplot inside to show
     # more information
     if (type == "violin") {
-      baseplot <- baseplot +
-        geom_boxplot(width = inner.box.width, fill = "white", outlier.colour = NA)
+      if (show.ci) {
+        baseplot <- baseplot +
+          geom_boxplot(width = inner.box.width, fill = "white", outlier.colour = NA, notch = TRUE)
+      } else {
+        baseplot <- baseplot +
+          geom_boxplot(width = inner.box.width, fill = "white", outlier.colour = NA)
+      }
     }
 
     # if we have boxplots or violon plots, also add a point that indicates
