@@ -16,7 +16,6 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "grp.est", "ci.low", "ci.h
 #' @param type Type of plot. Use one of following:
 #'          \describe{
 #'            \item{\code{"dots"}}{(or \code{"glm"} or \code{"or"} (default)) for odds or incident rate ratios (forest plot). Note that this type plots the exponentiated estimates, thus being appropriate only for specific link-functions.}
-#'            \item{\code{"slope"}}{to plot probability or incidents slopes (predicted probabilities or incidents) for each model term, where all remaining co-variates are set to zero (i.e. ignored). Use \code{facet.grid} to decide whether to plot each coefficient as separate plot or as integrated faceted plot.}
 #'            \item{\code{"eff"}}{to plot marginal effects of predicted probabilities or incidents for each model term, where all remaining co-variates are set to the mean (see 'Details'). Use \code{facet.grid} to decide whether to plot each coefficient as separate plot or as integrated faceted plot.}
 #'            \item{\code{"pred"}}{to plot predicted values for the response, related to specific model predictors. See 'Details'.}
 #'            \item{\code{"ma"}}{to check model assumptions. Note that the only relevant argument for this option is \code{fit}. All other arguments are ignored.}
@@ -161,11 +160,19 @@ sjp.glm <- function(fit,
                     prnt.plot = TRUE,
                     ...) {
 
-  if (stats::runif(1) < .2)
+  if (stats::runif(1) < .35)
     message("`sjp.glm()` will become deprecated in the future. Please use `plot_model()` instead.")
 
+  ## TODO activate in future update
+  # .Deprecated("plot_model")
+
   # check args -----
-  if (type == "pc" || type == "prob") type <- "slope"
+
+  if (type == "pc" || type == "prob" || type == "slope") {
+    message("This plot type has been removed, as it was misleading. Use `plot_model` with `type = \"pred\"` to plot marginal effects, or with `type = \"slope\"` for model diagnostisc.")
+    type <- "dots"
+  }
+
 
   if (inherits(fit, "logistf")) {
     # no model summary currently supported for logistf class
