@@ -48,7 +48,7 @@
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
 #'            \item the web page content (\code{page.content}),
-#'            \item the complete html-output (\code{output.complete}),
+#'            \item the complete html-output (\code{page.complete}),
 #'            \item the html-table with inline-css for use with knitr (\code{knitr}),
 #'            \item the \code{factor.index}, i.e. the column index of each variable with the highest factor loading for each factor and
 #'            \item the \code{removed.items}, i.e. which variables have been removed because they were outside of the \code{fctr.load.tlrn}'s range.
@@ -533,12 +533,12 @@ sjt.pca <- function(data,
   structure(class = c("sjTable", "sjtpca"),
                       list(page.style = page.style,
                            page.content = page.content,
-                           output.complete = toWrite,
+                           page.complete = toWrite,
                            knitr = knitr,
                            factor.index = factorindex,
                            removed.items = removableItems,
                            file = file,
                            header = table.header,
                            show = !no.output,
-                           use.viewer = use.viewer))
+                           viewer = use.viewer))
 }
