@@ -50,7 +50,7 @@
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
 #'            \item the web page content (\code{page.content}),
-#'            \item the complete html-output (\code{output.complete}) and
+#'            \item the complete html-output (\code{page.complete}) and
 #'            \item the html-table with inline-css for use with knitr (\code{knitr})
 #'            }
 #'            for further use.
@@ -78,9 +78,12 @@
 #'
 #' # print cross table with manually set
 #' # labels and expected values
-#' sjt.xtab(efc$e16sex, efc$e42dep, var.labels = c("Elder's gender",
-#'          "Elder's dependency"), value.labels = list(efc.labels[['e16sex']],
-#'          efc.labels[['e42dep']]), show.exp = TRUE)
+#' sjt.xtab(
+#'   efc$e16sex,
+#'   efc$e42dep,
+#'   var.labels = c("Elder's gender", "Elder's dependency"),
+#'   show.exp = TRUE
+#' )
 #'
 #' # print minimal cross table with labels, total col/row highlighted
 #' sjt.xtab(efc$e16sex, efc$e42dep, show.cell.prc = FALSE, emph.total = TRUE)
@@ -559,10 +562,10 @@ sjt.xtab <- function(var.row,
   structure(class = c("sjTable", "sjtxtab"),
                       list(page.style = page.style,
                            page.content = page.content,
-                           output.complete = toWrite,
+                           page.complete = toWrite,
                            knitr = knitr,
                            header = table.header,
                            file = file,
                            show = !no.output,
-                           use.viewer = use.viewer))
+                           viewer = use.viewer))
 }
