@@ -43,7 +43,7 @@
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
 #'            \item the web page content (\code{page.content}),
-#'            \item the complete html-output (\code{output.complete}) and
+#'            \item the complete html-output (\code{page.complete}) and
 #'            \item the html-table with inline-css for use with knitr (\code{knitr})
 #'            }
 #'            for further use.
@@ -461,10 +461,10 @@ sjt.stackfrq <- function(items,
   structure(class = c("sjTable", "sjtstackfrq"),
                       list(page.style = page.style,
                            page.content = page.content,
-                           output.complete = toWrite,
+                           page.complete = toWrite,
                            header = table.header,
                            knitr = knitr,
                            file = file,
                            show = !no.output,
-                           use.viewer = use.viewer))
+                           viewer = use.viewer))
 }
